@@ -33,12 +33,13 @@ from designateclient import version
 
 
 class DesignateAdapter(adapter.LegacyJsonAdapter):
-    """
-    Adapter around LegacyJsonAdapter.
+    """Adapter around LegacyJsonAdapter.
+
     The user can pass a timeout keyword that will apply only to
     the Designate Client, in order:
-        - timeout keyword passed to request()
-        - timeout attribute on keystone session
+
+    - timeout keyword passed to ``request()``
+    - timeout attribute on keystone session
     """
     def __init__(self, *args, **kwargs):
         self.timeout = kwargs.pop('timeout', None)
@@ -93,6 +94,8 @@ class DesignateAdapter(adapter.LegacyJsonAdapter):
             raise exceptions.NotFound(**response_payload)
         elif response.status_code == 409:
             raise exceptions.Conflict(**response_payload)
+        elif response.status_code == 413:
+            raise exceptions.OverQuota(**response_payload)
         elif response.status_code >= 500:
             raise exceptions.Unknown(**response_payload)
         return response, body
